@@ -23,7 +23,14 @@ def gather_imports(imp):
         top_package = os.path.dirname(m.__file__)
         module_import = True
     else:
-        top_package = __import__(m.__name__.split('.')[0]).__path__._path[0]
+        im = __import__(m.__name__.split('.')[0])
+        if isinstance(im, list):
+            print("im is a list")
+            print(im)
+        # the __path__ attribute *may* be a string in some cases. I had to fix this.
+        print("path.:",  __import__(m.__name__.split('.')[0]).__path__)
+        # top_package = __import__(m.__name__.split('.')[0]).__path__._path[0]
+        top_package = __import__(m.__name__.split('.')[0]).__path__[0]
         module_import = False
 
     found_hashes = {}
@@ -90,12 +97,13 @@ def gather_report_source_include(report):
     return sources
 
 
-def gather_upload_to_campusnet(report, output_dir=None):
+def gather_upload_to_campusnet(report, output_dir=None, token_include_plaintext_source=False):
     # n = report.nL
     args = parser.parse_args()
     results, table_data = evaluate_report(report, show_help_flag=False, show_expected=False, show_computed=False, silent=True,
                                           show_progress_bar=not args.noprogress,
-                                          big_header=not args.autolab)
+                                          big_header=not args.autolab,
+                                          )
     print("")
     sources = {}
     if not args.autolab:
@@ -123,10 +131,11 @@ def gather_upload_to_campusnet(report, output_dir=None):
             if hash in known_hashes and f_rel not in cov_files and use_coverage:
                 print("Skipping", f_rel)
             else:
-                s_include.append("#"*3 +" Content of " + f_rel +" " + "#"*3)
-                s_include.append("")
-                s_include.append(s['pycode'][f_rel])
-                s_include.append("")
+                if token_include_plaintext_source:
+                    s_include.append("#"*3 +" Content of " + f_rel +" " + "#"*3)
+                    s_include.append("")
+                    s_include.append(s['pycode'][f_rel])
+                    s_include.append("")
 
     if output_dir is None:
         output_dir = os.getcwd()
